@@ -1,8 +1,8 @@
 #!/usr/bin/python
 #
-# Author: Jashua R. Cloutier (contact via sourceforge username:senexcanis)
+# Author: Jashua R. Cloutier (jashuac@bellsouth.com)
 #
-# Copyright (C) 2010, Jashua R. Cloutier
+# Copyright (C) 2009, Jashua R. Cloutier
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -48,10 +48,9 @@ representing the class
 import ply.lex as lex
 import os
 import sys
-import re
 
-__version__ = "1.1"
-version = "1.1"
+__version__ = "1.05"
+
 tokens = [
     'NUMBER',
     'NAME',
@@ -78,9 +77,9 @@ tokens = [
     'NEW_LINE',
 ]
 
-t_ignore = " \t\r[].|!?%@"
+t_ignore = " \t\r~[].|!?%@"
 t_NUMBER = r'[0-9][0-9XxA-Fa-f]*'
-t_NAME = r'[<>A-Za-z_~][A-Za-z0-9_]*'
+t_NAME = r'[<>A-Za-z_][A-Za-z0-9_]*'
 t_OPERATOR_DIVIDE_OVERLOAD = r'/='
 t_OPEN_PAREN = r'\('
 t_CLOSE_PAREN = r'\)'
@@ -91,16 +90,7 @@ t_COLON = r':'
 t_COMMA = r','
 t_PRECOMP_MACRO = r'\#.*'
 t_PRECOMP_MACRO_CONT = r'.*\\\n'
-def t_COMMENT_SINGLELINE(t):
-    r'\/\/.*\n'
-    global doxygenCommentCache
-    if t.value.startswith("///") or t.value.startswith("//!"):
-        if doxygenCommentCache:
-            doxygenCommentCache += "\n"
-        if t.value.endswith("\n"):
-            doxygenCommentCache += t.value[:-1]
-        else:
-            doxygenCommentCache += t.value
+t_COMMENT_SINGLELINE = r'\/\/.*\n'
 t_ASTERISK = r'\*'
 t_MINUS = r'\-'
 t_PLUS = r'\+'
@@ -112,15 +102,7 @@ t_CHAR_LITERAL = "'.'"
 #TODO: This does not work with the string "bla \" bla"
 t_STRING_LITERAL = r'"([^"\\]|\\.)*"'
 #Found at http://ostermiller.org/findcomment.html
-def t_COMMENT_MULTILINE(t):
-    r'/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*+/'
-    global doxygenCommentCache
-    if t.value.startswith("/**") or t.value.startswith("/*!"):
-        #not sure why, but get double new lines
-        v = t.value.replace("\n\n", "\n")
-        #strip prefixing whitespace
-        v = re.sub("\n[\s]+\*", "\n*", v)
-        doxygenCommentCache += v
+t_COMMENT_MULTILINE = r'/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*+/'
 def t_NEWLINE(t):
     r'\n+'
     t.lexer.lineno += len(t.value)
@@ -137,16 +119,6 @@ supportedAccessSpecifier = [
     'private'
 ]
 
-doxygenCommentCache = ""
-
-def is_namespace(nameStack):
-    """Determines if a namespace is being specified"""
-    if len(nameStack) == 0:
-        return False
-    if nameStack[0] == "namespace":
-        return True
-    return False
-
 def is_enum_namestack(nameStack):
     """Determines if a namestack is an enum namestack"""
     if len(nameStack) == 0:
@@ -164,7 +136,6 @@ class CppClass(dict):
     
     Contains the following Keys:
     self['name'] - Name of the class
-    self['doxygen'] - Doxygen comments associated with the class if they exist
     self['inherits'] - List of Classes that this one inherits where the values
         are of the form {"access": Anything in supportedAccessSpecifier
                                   "class": Name of the class
@@ -201,14 +172,9 @@ class CppClass(dict):
     }
     """
     def __init__(self, nameStack):
-        if (debug): print "Class:   ",  nameStack
         if (len(nameStack) < 2):
             print "Error detecting class"
             return
-        global doxygenCommentCache
-        if len(doxygenCommentCache):
-            self["doxygen"] = doxygenCommentCache
-            doxygenCommentCache = ""
         self["name"] = nameStack[1]
         inheritList = []
         if ":" in nameStack:
@@ -245,14 +211,10 @@ class CppClass(dict):
         self['methods'] = methodAccessSpecificList
         self['properties'] = propertyAccessSpecificList
         self['enums'] = enumAccessSpecificList
-        self['namespace'] = ""
 
     def __repr__(self):
         """Convert class to a string"""
-        rtn = "class %s\n"%(self["namespace"] + self["name"])
-        try:
-            print self["doxygen"], 
-        except: pass
+        rtn = "class %s\n"%(self["name"])
         if "inherits" in self.keys():
             rtn += "Inherits: "
             for inheritClass in self["inherits"]:
@@ -285,64 +247,26 @@ class CppMethod(dict):
     Contains the following Keys:
     self['rtnType'] - Return type of the method (ex. "int")
     self['name'] - Name of the method (ex. "getSize")
-    self['doxygen'] - Doxygen comments associated with the method if they exist
     self['parameters'] - List of CppVariables
     """
     def __init__(self, nameStack):
         if (debug): print "Method:   ",  nameStack
-        global doxygenCommentCache
-        if len(doxygenCommentCache):
-            self["doxygen"] = doxygenCommentCache
-            doxygenCommentCache = ""
-        if "operator" in nameStack:
-            self["rtnType"] = " ".join(nameStack[:nameStack.index('operator')])
-            self["name"] = "".join(nameStack[nameStack.index('operator'):nameStack.index('(')])
-        else:
-            self["rtnType"] = " ".join(nameStack[:nameStack.index('(') - 1])
-            self["name"] = " ".join(nameStack[nameStack.index('(') - 1:nameStack.index('(')])
+        self["rtnType"] = " ".join(nameStack[:nameStack.index('(') - 1])
         if len(self["rtnType"]) == 0:
             self["rtnType"] = "void"
+        self["name"] = " ".join(nameStack[nameStack.index('(') - 1:nameStack.index('(')])
         paramsStack = nameStack[nameStack.index('(') + 1: ]
         #Remove things from the stack till we hit the last paren, this helps handle abstract and normal methods
         while (paramsStack[-1]  != ")"):
             paramsStack.pop()
         paramsStack.pop()
         params = []
-        #See if there is a doxygen comment for the variable
-        doxyVarDesc = {}
-        #TODO: Put this into a class
-        if self.has_key("doxygen"):
-            doxyLines = self["doxygen"].split("\n")
-            lastParamDesc = ""
-            for doxyLine in doxyLines:
-                if " @param " in doxyLine or " \param " in doxyLine:
-                    try:
-                        #Strip out the param
-                        doxyLine = doxyLine[doxyLine.find("param ") + 6:]
-                        (var, desc) = doxyLine.split(" ", 1)
-                        doxyVarDesc[var] = desc.strip()
-                        lastParamDesc = var
-                    except: pass
-                if " @return " in doxyLine or " \return " in doxyLine:
-                    lastParamDesc = ""
-                    # not handled for now
-                elif lastParamDesc:
-                    try:
-                        doxyLine = doxyLine.strip()
-                        if " " not in doxyLine:
-                            lastParamDesc = ""
-                            continue
-                        doxyLine = doxyLine[doxyLine.find(" ") + 1:]
-                        doxyVarDesc[lastParamDesc] += " " + doxyLine
-                    except: pass
-                    
-        #Create the variable now
         while (len(paramsStack)):
             if (',' in paramsStack):
-                params.append(CppVariable(paramsStack[0:paramsStack.index(',')],  doxyVarDesc=doxyVarDesc))
+                params.append(CppVariable(paramsStack[0:paramsStack.index(',')]))
                 paramsStack = paramsStack[paramsStack.index(',') + 1:]
             else:
-                param = CppVariable(paramsStack,  doxyVarDesc=doxyVarDesc)
+                param = CppVariable(paramsStack)
                 if len(param.keys()):
                     params.append(param)
                 break
@@ -355,20 +279,13 @@ class CppVariable(dict):
     Contains the following Keys:
     self['type'] - Type for the variable (ex. "const string &")
     self['name'] - Name of the variable (ex. "numItems")
-    self['namespace'] - Namespace containing the enum
-    self['desc'] - Description of the variable if part of a method (optional)
-    self['doxygen'] - Doxygen comments associated with the method if they exist
     self['defaltValue'] - Default value of the variable, this key will only
         exist if there is a default value
     """
-    def __init__(self, nameStack,  **kwargs):
+    def __init__(self, nameStack):
         if (debug): print "Variable: ",  nameStack
         if (len(nameStack) < 2):
             return
-        global doxygenCommentCache
-        if len(doxygenCommentCache):
-            self["doxygen"] = doxygenCommentCache
-            doxygenCommentCache = ""
         if ("=" in nameStack):
             self["type"] = " ".join(nameStack[:nameStack.index("=") - 1])
             self["name"] = nameStack[nameStack.index("=") - 1]
@@ -380,17 +297,12 @@ class CppVariable(dict):
         self["type"] = self["type"].replace(": ",":")
         self["type"] = self["type"].replace(" <","<")
         self["type"] = self["type"].replace(" >",">")
-        #Optional doxygen description
-        try:
-            self["desc"] = kwargs["doxyVarDesc"][self["name"]]
-        except: pass
 
 class CppEnum(dict):
     """Takes a name stack and turns it into an Enum
     
     Contains the following Keys:
     self['name'] - Name of the enum (ex. "ItemState")
-    self['namespace'] - Namespace containing the enum
     self['values'] - List of values where the values are a dictionary of the
         form {"name": name of the key (ex. "PARSING_HEADER"),
                   "value": Specified value of the enum, this key will only exist
@@ -434,8 +346,7 @@ class CppEnum(dict):
             for var in postBraceStack:
                 if "," in var:
                     continue
-                self["instances"].append(var)
-        self["namespace"] = ""
+                self["instances"].append(var)                
 
 class CppHeader:
     """Parsed C++ class header
@@ -446,11 +357,11 @@ class CppHeader:
     """
     def __init__(self, headerFileName, argType = "file"):
         if (argType == "file"):
-            self.headerFileName = os.path.expandvars(headerFileName)
+            self.headerFileName = headerFileName
             self.mainClass = os.path.split(self.headerFileName)[1][:-2]
             headerFileStr = ""
-#            if headerFileName[-2:] != ".h":
-#                raise Exception("file must be a header file and end with .h")
+            if headerFileName[-2:] != ".h":
+                raise Exception("file must be a header file and end with .h")
         elif argType == "string":
             self.headerFileName = ""
             self.mainClass = "???"
@@ -459,10 +370,7 @@ class CppHeader:
             raise Exception("Arg type must be either file or string")
         self.curClass = ""
         self.classes = {}
-        self.enums = []
         self.nameStack = []
-        self.nameSpaces = []
-        self.nameSpaceDepth = 0
         self.curAccessSpecifier = 'private'
     
         if (len(self.headerFileName)):
@@ -481,26 +389,15 @@ class CppHeader:
                 curLine = tok.lineno
                 curChar = tok.lexpos
                 if (tok.type == 'OPEN_BRACE'):
-                    if len(self.nameStack) and is_namespace(self.nameStack):
-#                        print "Saw namespace %s depth %d"%(self.nameStack[1],self.braceDepth)
-                        self.nameSpaces.append(self.nameStack[1])
-                        self.nameSpaceDepth +=1
                     if len(self.nameStack) and not is_enum_namestack(self.nameStack):
                         self.evaluateStack()
                     else:
                         self.nameStack.append(tok.value)
                     self.braceDepth += 1
                 elif (tok.type == 'CLOSE_BRACE'):
-                    if self.braceDepth == 0:
-                        continue
-#                    print "Brace Depth %d Namespace depth %d"%(self.braceDepth,self.nameSpaceDepth)
-                    if (self.braceDepth == self.nameSpaceDepth):
-                        self.nameSpaceDepth -=1
-                        tmp = self.nameSpaces.pop()
-#                        print "Exiting namespace %s"%tmp
                     if len(self.nameStack) and is_enum_namestack(self.nameStack):
                         self.nameStack.append(tok.value)
-                    elif self.braceDepth < 10:
+                    elif self.braceDepth < 2:
                         self.evaluateStack()
                     else:
                         self.nameStack = []
@@ -537,7 +434,7 @@ class CppHeader:
                         continue
                     self.nameStack.append(tok.value)
                 elif (tok.type == 'SEMI_COLON'):
-                    if (self.braceDepth < 10):
+                    if (self.braceDepth < 2):
                         self.evaluateStack()
         except:
             raise CppParseError("Not able to parse %s on line %d evaluating \"%s\"\nError around: %s"
@@ -545,7 +442,6 @@ class CppHeader:
         
     def evaluateStack(self):
         """Evaluates the current name stack"""
-        global doxygenCommentCache
         if (len(self.curClass)):
             if (debug): print "%s (%s) "%(self.curClass, self.curAccessSpecifier), 
         if (len(self.nameStack) == 0):
@@ -553,24 +449,16 @@ class CppHeader:
             return
         elif (self.nameStack[0] == "class"):
             self.evaluateClassStack()
-        elif (self.nameStack[0] == "struct"):
-            self.curAccessSpecifier = "public"
-            self.evaluateClassStack()
         elif (len(self.curClass) == 0):
-            if is_enum_namestack(self.nameStack):
-                self.evaluateEnumStack()
             self.nameStack = []
-            doxygenCommentCache = ""
             return
         elif (self.braceDepth < 1):
             #Ignore global stuff for now
             if (debug): print "Global stuff: ",  self.nameStack
             self.nameStack = []
-            doxygenCommentCache = ""
             return
         elif (self.braceDepth > 1):
             self.nameStack = []
-            doxygenCommentCache = ""
             return
         elif is_enum_namestack(self.nameStack):
             #elif self.nameStack[0] == "enum":
@@ -580,7 +468,6 @@ class CppHeader:
         else:
             self.evaluatePropertyStack()
         self.nameStack = []
-        doxygenCommentCache = ""
     
     def evaluateClassStack(self):
         """Create a Class out of the name stack (but not its parts)"""
@@ -593,7 +480,6 @@ class CppHeader:
             self.classes[self.curClass] = newClass
         else:
             self.curClass = ""
-        newClass["namespace"] = self.cur_namespace()
 
     def evaluateMethodStack(self):
         """Create a method out of the name stack"""
@@ -611,13 +497,7 @@ class CppHeader:
         """Create an Enum out of the name stack"""
         newEnum = CppEnum(self.nameStack)
         if len(newEnum.keys()):
-            if len(self.curClass):
-                newEnum["namespace"] = self.cur_namespace() + self.curClass + "::"
-                self.classes[self.curClass]["enums"][self.curAccessSpecifier].append(newEnum)
-            else:
-                newEnum["namespace"] = self.cur_namespace()                            
-#                print "Adding global enum"
-                self.enums.append(newEnum)
+            self.classes[self.curClass]["enums"][self.curAccessSpecifier].append(newEnum)
             #This enum has instances, turn them into properties
             if newEnum.has_key("instances"):
                 instanceType = "enum"
@@ -628,16 +508,6 @@ class CppHeader:
                     self.evaluatePropertyStack()
                 del newEnum["instances"]
 
-    def cur_namespace(self):
-        rtn = ""
-        i = 0
-        while i < len(self.nameSpaces):
-            rtn += self.nameSpaces[i]
-            rtn += "::"
-            i+=1
-        return rtn
-    
-    
     def __repr__(self):
         rtn = ""
         for className in self.classes.keys():
